@@ -19,7 +19,7 @@ class SddmKcm : public KQuickAddons::ManagedConfigModule
     Q_PROPERTY(SddmSettings *sddmSettings READ sddmSettings CONSTANT)
     Q_PROPERTY(ThemesModel *themesModel READ themesModel CONSTANT)
 public:
-    explicit SddmKcm(QObject *parent, const QVariantList &args);
+    explicit SddmKcm(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
     ~SddmKcm() override;
 
     Q_INVOKABLE static QString toLocalFile(const QUrl &url);
@@ -35,7 +35,7 @@ public:
 public Q_SLOTS:
     void save() override;
 Q_SIGNALS:
-    void errorOccured(const QString &message);
+    void errorOccured(const QString &untranslatedMessage);
     void syncSuccessful();
     void resetSyncedDataSuccessful();
 
